@@ -46,9 +46,18 @@ class LoggingSetup:
         self.default_syslog_level = self.default_level
         self.default_smtp_level = logging.WARNING
 
-        self.formatter = logging.Formatter("%(asctime)s - %(levelname)s - %(message)s")
-        self.formatter_without_timestamp = logging.Formatter("%(levelname)s - %(message)s")
-        self.formatter_tagged_format = ": %(levelname)s - %(message)s"
+        self.formatter = FancyFormatter(
+            "%(asctime)s - %(levelname)s - %(name)s: %(message)s",
+            "%(asctime)s - %(levelname)s - %(message)s",
+        )
+        self.formatter_without_timestamp = FancyFormatter(
+            "%(levelname)s - %(name)s: %(message)s",
+            "%(levelname)s - %(message)s",
+        )
+        self.formatter_tagged_format = (
+            "%s: %(levelname)s - %(name)s: %(message)s",
+            "%s: %(levelname)s - %(message)s",
+        )
 
     def setup(self):
         if self.app_name is None:
@@ -101,7 +110,10 @@ class LoggingSetup:
                     parts = address.split(":")
                     address = (parts[0], parts[1])
             handler = logging.handlers.SysLogHandler(address)
-            handler.setFormatter(logging.Formatter(tag + self.formatter_tagged_format))
+            handler.setFormatter(FancyFormatter(
+                self.formatter_tagged_format[0] % tag,
+                self.formatter_tagged_format[1] % tag
+            ))
             handler.setLevel(self.default_syslog_level)
             logger.addHandler(handler)
 
@@ -130,6 +142,40 @@ class LoggingSetup:
             logger.addHandler(handler)
 
 
+class FancyFormatter(logging.Formatter):
+    formatter_root = None
+
+    # noinspection PyMissingConstructor
+    def __init__(self, fmt, fmt_root=None):
+        self.formatter = logging.Formatter(fmt)
+        if fmt_root is not None:
+            self.formatter_root = logging.Formatter(fmt_root)
+
+    def formatTime(self, record, datefmt=None):
+        if record.name == "root" and self.formatter_root:
+            return self.formatter_root.formatTime(record, datefmt)
+        return self.formatter.formatTime(record, datefmt)
+
+    def formatException(self, ei):
+        return self.formatter.formatException(ei)
+
+    def usesTime(self):
+        return self.formatter.usesTime() or self.formatter_root and self.formatter_root.usesTime()
+
+    def formatMessage(self, record):
+        if record.name == "root" and self.formatter_root:
+            return self.formatter_root.formatMessage(record)
+        return self.formatter.formatMessage(record)
+
+    def formatStack(self, stack_info):
+        return self.formatter.formatStack(stack_info)
+
+    def format(self, record):
+        if record.name == "root" and self.formatter_root:
+            return self.formatter_root.format(record)
+        return self.formatter.format(record)
+
+
 class LessThanFilter(logging.Filter):
     def __init__(self, exclusive_maximum, name="lessThanFilter"):
         super(LessThanFilter, self).__init__(name)
