@@ -27,13 +27,15 @@ class Process:
     hidden = True
     exception = None
 
-    def __init__(self, command, timeout=3600, block=True, encoding=None, popen_override=None):
+    def __init__(self, command, timeout=3600, block=True, encoding=None, popen_override=None, shell=True, hidden=True):
         self.command = command
         self.popen_override = popen_override
         self.timeout = timeout
         self.block = block
         if encoding is not None:
             self.encoding = encoding
+        self.shell = shell
+        self.hidden = hidden
 
     def execute(self, input=None, callback=None):
         self.thread = threading.Thread(target=self.target, args=(input, callback), daemon=True)
@@ -43,7 +45,8 @@ class Process:
             threading.Thread(target=self.killer, daemon=True).start()
 
         if self.block:
-            self.thread.join()
+            while self.thread.is_alive():
+                self.thread.join(1)
         else:
             while self.process is None and self.exception is None:
                 pass
@@ -185,8 +188,12 @@ def detect_encoding():
     return _detected_encoding
 
 
-def execute_command(command, timeout=60, valid_codes=0):
-    process = Process(command, timeout=timeout, encoding=detect_encoding()).execute()
+def execute_command(command, timeout=60, valid_codes=0, encoding=None, popen_override=None, shell=True, hidden=True):
+    if encoding is None:
+        encoding = detect_encoding()
+    process = Process(
+        command, timeout=timeout, encoding=encoding, popen_override=popen_override, shell=shell, hidden=hidden
+    ).execute()
 
     if not isinstance(valid_codes, list):
         valid_codes = [valid_codes]
